class DefaultHandler:
    """
    持有handler的实例
    """

    plain = None
    guild = None
    guild_member = None
    channel = None
    message = None
    at_message = None
    direct_message = None
    audio = None
